QoreidData class

Constructors

QoreidData({Map<String, dynamic>? addressData, Map<String, dynamic>? applicantData, String? sessionToken, Map<String, dynamic>? identityData, String? ocrAcceptedDocuments})

Properties

addressData Map<String, dynamic>?
final
applicantData Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
identityData Map<String, dynamic>?
final
ocrAcceptedDocuments String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionToken String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited